@@ -22,15 +22,17 @@
 
 #include "gdaIncludes.h"
 
-class gdaConnection {
+namespace gda {
+
+class Connection {
 	public:
-		gdaConnection();
-		gdaConnection(Gda_Connection *a);
-		gdaConnection(CORBA_ORB orb);
-		~gdaConnection();
+		Connection();
+		Connection(GdaConnection *a);
+		Connection(CORBA_ORB orb);
+		~Connection();
 		
-		Gda_Connection* getCStruct();
-		void setCStruct(Gda_Connection *cnc);
+		GdaConnection* getCStruct();
+		void setCStruct(GdaConnection *cnc);
 		
 		void setProvider(gchar* name);
 		const gchar* getProvider();
@@ -38,16 +40,16 @@ class gdaConnection {
 		void setDefaultDB(gchar* dsn);
 		gint open(gchar* dsn, gchar* user,gchar* pwd);	
 		void close();
-		gdaErrorList *getErrors();
+		ErrorList *getErrors();
 		gint beginTransaction();
 		gint commitTransaction();
 		gint rollbackTransaction();
-		gdaRecordset* execute(gchar* txt, gulong* reccount, gulong flags);
+		Recordset* execute(gchar* txt, gulong* reccount, gulong flags);
 		gint startLogging(gchar* filename);
 		gint stopLogging();
 	
-		void addSingleError(gdaError* error);
-		void addErrorlist(gdaErrorList* list);
+		void addSingleError(Error* error);
+		void addErrorlist(ErrorList* list);
 
 		gboolean isOpen();
 		gchar* getDSN();
@@ -64,7 +66,9 @@ class gdaConnection {
 		gchar* getVersion();
 			
 	private:
-		Gda_Connection* _gda_connection;
+		GdaConnection* _gda_connection;
+};
+
 };
 
 #endif // __gda_bindings_cpp_gdaConnectionH
