@@ -26,8 +26,8 @@
 extern "C" {
 #endif
 
-#define GDA_CONFIG_SECTION_DATASOURCES "/gda/Datasources"
-#define GDA_CONFIG_SECTION_LOG         "/gda/Log"
+#define GDA_CONFIG_SECTION_DATASOURCES "/apps/gda/Datasources"
+#define GDA_CONFIG_SECTION_LOG         "/apps/gda/Log"
 
 /*
  * Configuration system access
@@ -56,53 +56,51 @@ void     gda_config_free_list      (GList *list);
 /*
  * Providers
  */
-typedef struct _Gda_Provider
-{
-  gchar* name;
-  gchar* comment;
-  gchar* location;
-  gchar* repo_id;
-  gchar* type;
-  gchar* username;
-  gchar* hostname;
-  gchar* domain;
-  GList* dsn_params;
-} Gda_Provider;
+typedef struct _GdaProvider {
+	gchar* name;
+	gchar* comment;
+	gchar* location;
+	gchar* repo_id;
+	gchar* type;
+	gchar* username;
+	gchar* hostname;
+	gchar* domain;
+	GList* dsn_params;
+} GdaProvider;
 
-#define GDA_PROVIDER_TYPE(srv)       ((srv) ? (srv)->type : 0)
-#define GDA_PROVIDER_NAME(srv)       ((srv) ? (srv)->name : 0)
-#define GDA_PROVIDER_COMMENT(srv)    ((srv) ? (srv)->comment : 0)
-#define GDA_PROVIDER_LOCATION(srv)   ((srv) ? (srv)->location : 0)
-#define GDA_PROVIDER_REPO_ID(srv)    ((srv) ? (srv)->repo_id : 0)
-#define GDA_PROVIDER_USERNAME(srv)   ((srv) ? (srv)->username : 0)
-#define GDA_PROVIDER_HOSTNAME(srv)   ((srv) ? (srv)->hostname : 0)
-#define GDA_PROVIDER_DOMAIN(srv)     ((srv) ? (srv)->domain : 0)
-#define GDA_PROVIDER_DSN_PARAMS(srv) ((srv) ? (srv)->dsn_params : 0)
+#define GDA_PROVIDER_TYPE(srv)       ((srv) ? (srv)->type : NULL)
+#define GDA_PROVIDER_NAME(srv)       ((srv) ? (srv)->name : NULL)
+#define GDA_PROVIDER_COMMENT(srv)    ((srv) ? (srv)->comment : NULL)
+#define GDA_PROVIDER_LOCATION(srv)   ((srv) ? (srv)->location : NULL)
+#define GDA_PROVIDER_REPO_ID(srv)    ((srv) ? (srv)->repo_id : NULL)
+#define GDA_PROVIDER_USERNAME(srv)   ((srv) ? (srv)->username : NULL)
+#define GDA_PROVIDER_HOSTNAME(srv)   ((srv) ? (srv)->hostname : NULL)
+#define GDA_PROVIDER_DOMAIN(srv)     ((srv) ? (srv)->domain : NULL)
+#define GDA_PROVIDER_DSN_PARAMS(srv) ((srv) ? (srv)->dsn_params : NULL)
 
-Gda_Provider* gda_provider_new          (void);
-Gda_Provider* gda_provider_copy         (Gda_Provider*);
-void          gda_provider_free         (Gda_Provider*);
+GdaProvider* gda_provider_new          (void);
+GdaProvider* gda_provider_copy         (GdaProvider *provider);
+void         gda_provider_free         (GdaProvider *provider);
 
-GList*        gda_provider_list         (void);
-void          gda_provider_free_list    (GList* list);
-Gda_Provider* gda_provider_find_by_name (const gchar* provider);
+GList*       gda_provider_list         (void);
+void         gda_provider_free_list    (GList* list);
+GdaProvider* gda_provider_find_by_name (const gchar* name);
 
 /*
  * Data sources
  */
 GList*      gda_list_datasources              (void);
-GList*      gda_list_datasources_for_provider (gchar* provider);
+GList*      gda_list_datasources_for_provider (gchar* name);
 
-typedef struct _Gda_Dsn
-{
-  gchar*   gda_name;
-  gchar*   provider;
-  gchar*   dsn_str;
-  gchar*   description;
-  gchar*   username;
-  gchar*   config;
-  gboolean is_global;
-} Gda_Dsn;
+typedef struct _GdaDsn {
+	gchar*   gda_name;
+	gchar*   provider;
+	gchar*   dsn_str;
+	gchar*   description;
+	gchar*   username;
+	gchar*   config;
+	gboolean is_global;
+} GdaDsn;
 
 #define GDA_DSN_GDA_NAME(dsn)    ((dsn) ? (dsn)->gda_name : 0)
 #define GDA_DSN_PROVIDER(dsn)    ((dsn) ? (dsn)->provider : 0)
@@ -112,21 +110,21 @@ typedef struct _Gda_Dsn
 #define GDA_DSN_CONFIG(dsn)      ((dsn) ? (dsn)->config : 0)
 #define GDA_DSN_IS_GLOBAL(dsn)   ((dsn) ? (dsn)->is_global : FALSE)
 
-#define  gda_dsn_new() g_new0(Gda_Dsn, 1)
-void     gda_dsn_free            (Gda_Dsn *dsn);
-Gda_Dsn* gda_dsn_copy            (Gda_Dsn *dsn);
+#define  gda_dsn_new() g_new0(GdaDsn, 1)
+void     gda_dsn_free            (GdaDsn *dsn);
+GdaDsn*  gda_dsn_copy            (GdaDsn *dsn);
 
-Gda_Dsn* gda_dsn_find_by_name    (const gchar *dsn_name);
-void     gda_dsn_set_name        (Gda_Dsn *dsn, const gchar *name);
-void     gda_dsn_set_provider    (Gda_Dsn *dsn, const gchar *provider);
-void     gda_dsn_set_dsn         (Gda_Dsn *dsn, const gchar *dsn_str);
-void     gda_dsn_set_description (Gda_Dsn *dsn, const gchar *description);
-void     gda_dsn_set_username    (Gda_Dsn *dsn, const gchar *username);
-void     gda_dsn_set_config      (Gda_Dsn *dsn, const gchar *config);
-void     gda_dsn_set_global      (Gda_Dsn *dsn, gboolean is_global);
+GdaDsn*  gda_dsn_find_by_name    (const gchar *dsn_name);
+void     gda_dsn_set_name        (GdaDsn *dsn, const gchar *name);
+void     gda_dsn_set_provider    (GdaDsn *dsn, const gchar *provider);
+void     gda_dsn_set_dsn         (GdaDsn *dsn, const gchar *dsn_str);
+void     gda_dsn_set_description (GdaDsn *dsn, const gchar *description);
+void     gda_dsn_set_username    (GdaDsn *dsn, const gchar *username);
+void     gda_dsn_set_config      (GdaDsn *dsn, const gchar *config);
+void     gda_dsn_set_global      (GdaDsn *dsn, gboolean is_global);
 
-gboolean gda_dsn_save            (Gda_Dsn *dsn);
-gboolean gda_dsn_remove          (Gda_Dsn *dsn);
+gboolean gda_dsn_save            (GdaDsn *dsn);
+gboolean gda_dsn_remove          (GdaDsn *dsn);
 
 GList*   gda_dsn_list            (void);
 void     gda_dsn_free_list       (GList *list);
