@@ -19,7 +19,7 @@
 #include "gda-interbase.h"
 
 gboolean
-gda_interbase_connection_new (Gda_ServerConnection *cnc)
+gda_interbase_connection_new (GdaServerConnection *cnc)
 {
   INTERBASE_Connection* ib_cnc;
 
@@ -34,13 +34,13 @@ gda_interbase_connection_new (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_interbase_connection_open (Gda_ServerConnection *cnc,
+gda_interbase_connection_open (GdaServerConnection *cnc,
                                const gchar *dsn,
                                const gchar *user,
                                const gchar *password)
 {
   INTERBASE_Connection* ib_cnc;
-  Gda_ServerError*  error;
+  GdaServerError*  error;
 
   g_return_val_if_fail(cnc != NULL, -1);
 
@@ -60,7 +60,7 @@ gda_interbase_connection_open (Gda_ServerConnection *cnc,
 }
 
 void
-gda_interbase_connection_close (Gda_ServerConnection *cnc)
+gda_interbase_connection_close (GdaServerConnection *cnc)
 {
   INTERBASE_Connection* ib_cnc;
 
@@ -75,7 +75,7 @@ gda_interbase_connection_close (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_interbase_connection_begin_transaction (Gda_ServerConnection *cnc)
+gda_interbase_connection_begin_transaction (GdaServerConnection *cnc)
 {
   INTERBASE_Connection* ib_cnc;
 
@@ -98,7 +98,7 @@ gda_interbase_connection_begin_transaction (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_interbase_connection_commit_transaction (Gda_ServerConnection *cnc)
+gda_interbase_connection_commit_transaction (GdaServerConnection *cnc)
 {
   INTERBASE_Connection* ib_cnc;
 
@@ -118,7 +118,7 @@ gda_interbase_connection_commit_transaction (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_interbase_connection_rollback_transaction (Gda_ServerConnection *cnc)
+gda_interbase_connection_rollback_transaction (GdaServerConnection *cnc)
 {
   INTERBASE_Connection* ib_cnc;
 
@@ -137,9 +137,9 @@ gda_interbase_connection_rollback_transaction (Gda_ServerConnection *cnc)
   return -1;
 }
 
-Gda_ServerRecordset *
-gda_interbase_connection_open_schema (Gda_ServerConnection *cnc,
-                                      Gda_ServerError *error,
+GdaServerRecordset *
+gda_interbase_connection_open_schema (GdaServerConnection *cnc,
+                                      GdaServerError *error,
                                       GDA_Connection_QType t,
                                       GDA_Connection_Constraint *constraints,
                                       gint length)
@@ -148,7 +148,7 @@ gda_interbase_connection_open_schema (Gda_ServerConnection *cnc,
 }
 
 glong
-gda_interbase_connection_modify_schema (Gda_ServerConnection *cnc,
+gda_interbase_connection_modify_schema (GdaServerConnection *cnc,
                                         GDA_Connection_QType t,
                                         GDA_Connection_Constraint *constraints,
                                         gint length)
@@ -157,27 +157,27 @@ gda_interbase_connection_modify_schema (Gda_ServerConnection *cnc,
 }
 
 gint
-gda_interbase_connection_start_logging (Gda_ServerConnection *cnc,
+gda_interbase_connection_start_logging (GdaServerConnection *cnc,
                                         const gchar *filename)
 {
   return -1;
 }
 
 gint
-gda_interbase_connection_stop_logging (Gda_ServerConnection *cnc)
+gda_interbase_connection_stop_logging (GdaServerConnection *cnc)
 {
   return -1;
 }
 
 gchar *
-gda_interbase_connection_create_table (Gda_ServerConnection *cnc,
+gda_interbase_connection_create_table (GdaServerConnection *cnc,
                                        GDA_RowAttributes *columns)
 {
   return NULL;
 }
 
 gboolean
-gda_interbase_connection_supports (Gda_ServerConnection *cnc,
+gda_interbase_connection_supports (GdaServerConnection *cnc,
                                    GDA_Connection_Feature feature)
 {
   g_return_val_if_fail(cnc != NULL, FALSE);
@@ -188,7 +188,7 @@ gda_interbase_connection_supports (Gda_ServerConnection *cnc,
 }
 
 GDA_ValueType
-gda_interbase_connection_get_gda_type (Gda_ServerConnection *cnc, gulong sql_type)
+gda_interbase_connection_get_gda_type (GdaServerConnection *cnc, gulong sql_type)
 {
   g_return_val_if_fail(cnc != NULL, GDA_TypeNull);
 
@@ -221,7 +221,7 @@ gda_interbase_connection_get_gda_type (Gda_ServerConnection *cnc, gulong sql_typ
 }
 
 gshort
-gda_interbase_connection_get_c_type (Gda_ServerConnection *cnc, GDA_ValueType type)
+gda_interbase_connection_get_c_type (GdaServerConnection *cnc, GDA_ValueType type)
 {
   g_return_val_if_fail(cnc != NULL, -1);
 
@@ -231,8 +231,20 @@ gda_interbase_connection_get_c_type (Gda_ServerConnection *cnc, GDA_ValueType ty
   return -1;
 }
 
+gchar *
+gda_interbase_connection_sql2xml (GdaServerConnection *cnc, const gchar *sql)
+{
+  return NULL;
+}
+
+gchar *
+gda_interbase_connection_xml2sql (GdaServerConnection *cnc, const gchar *xml)
+{
+  return NULL;
+}
+
 void
-gda_interbase_connection_free (Gda_ServerConnection *cnc)
+gda_interbase_connection_free (GdaServerConnection *cnc)
 {
   INTERBASE_Connection* ib_cnc;
 
@@ -246,9 +258,9 @@ gda_interbase_connection_free (Gda_ServerConnection *cnc)
 }
 
 void
-gda_interbase_error_make (Gda_ServerError *error,
-                          Gda_ServerRecordset *recset,
-                          Gda_ServerConnection *cnc,
+gda_interbase_error_make (GdaServerError *error,
+                          GdaServerRecordset *recset,
+                          GdaServerConnection *cnc,
                           gchar *where)
 {
   gchar*                err_msg; /* FIXME: retireve error message from server */
