@@ -19,8 +19,8 @@
 
 #include "gda-mysql.h"
 
-static Gda_ServerImpl*         server_impl = NULL;
-static Gda_ServerImplFunctions server_impl_functions =
+static GdaServerImpl*         server_impl = NULL;
+static GdaServerImplFunctions server_impl_functions =
 {
   gda_mysql_connection_new,
   gda_mysql_connection_open,
@@ -36,6 +36,8 @@ static Gda_ServerImplFunctions server_impl_functions =
   gda_mysql_connection_supports,
   gda_mysql_connection_get_gda_type,
   gda_mysql_connection_get_c_type,
+  gda_mysql_connection_sql2xml,
+  gda_mysql_connection_xml2sql,
   gda_mysql_connection_free,
 
   gda_mysql_command_new,
