@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-sybase-connection.c,v 1.7 2000/11/27 17:50:27 rodrigo Exp $
+ * $Id: gda-sybase-connection.c,v 1.9 2001/04/07 08:49:31 rodrigo Exp $
  *
  * GNOME DB Sybase Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -22,6 +22,20 @@
  */
 
 // $Log: gda-sybase-connection.c,v $
+// Revision 1.9  2001/04/07 08:49:31  rodrigo
+// 2001-04-07  Rodrigo Moya <rodrigo@gnome-db.org>
+//
+// 	* objects renaming (Gda_* to Gda*) to conform to the GNOME
+// 	naming standards
+//
+// Revision 1.8  2001/02/14 17:31:59  rodrigo
+// 2001-02-14	Rodrigo Moya <rodrigo@gnome-db.org>
+//
+// 	* idl/GDA_Connection.idl: added new conversion methods
+// 	(xml2sql and sql2xml)
+// 	* lib/gda-client/gda-connection.[ch],
+// 	lib/gda-server/*, providers/*: added new IDL methods
+//
 // Revision 1.7  2000/11/27 17:50:27  rodrigo
 // 2000-11-27	Rodrigo Moya <rodrigo@gnome-db.org>
 //
@@ -59,8 +73,8 @@
 #include "gda-sybase.h"
 #include "ctype.h"
 
-typedef Gda_ServerRecordset* (*schema_ops_fn)(Gda_ServerError *,
-                                              Gda_ServerConnection *,
+typedef GdaServerRecordset* (*schema_ops_fn)(GdaServerError *,
+                                              GdaServerConnection *,
                                               GDA_Connection_Constraint *,
                                               gint);
 
@@ -69,24 +83,24 @@ schema_ops_fn schema_ops[GDA_Connection_GDCN_SCHEMA_LAST] = {
 };
 
 // schema definitions
-static Gda_ServerRecordset*
-schema_cols (Gda_ServerError *,
-	     Gda_ServerConnection *,
+static GdaServerRecordset*
+schema_cols (GdaServerError *,
+	     GdaServerConnection *,
 	     GDA_Connection_Constraint *,
 	     gint);
-static Gda_ServerRecordset*
-schema_procs(Gda_ServerError *,
-	     Gda_ServerConnection *,
+static GdaServerRecordset*
+schema_procs(GdaServerError *,
+	     GdaServerConnection *,
 	     GDA_Connection_Constraint *,
 	     gint);
-static Gda_ServerRecordset*
-schema_tables (Gda_ServerError *,
-	       Gda_ServerConnection *,
+static GdaServerRecordset*
+schema_tables (GdaServerError *,
+	       GdaServerConnection *,
 	       GDA_Connection_Constraint *,
 	       gint);
-static Gda_ServerRecordset*
-schema_types (Gda_ServerError *,
-	      Gda_ServerConnection *,
+static GdaServerRecordset*
+schema_types (GdaServerError *,
+	      GdaServerConnection *,
 	      GDA_Connection_Constraint *,
 	      gint);
 
@@ -94,9 +108,9 @@ schema_types (Gda_ServerError *,
 
 // Further non-public definitions
 static gint
-gda_sybase_init_dsn_properties(Gda_ServerConnection *, const gchar *);
+gda_sybase_init_dsn_properties(GdaServerConnection *, const gchar *);
 static gboolean
-gda_sybase_set_locale(Gda_ServerConnection *, const gchar *);
+gda_sybase_set_locale(GdaServerConnection *, const gchar *);
 
 //  utility functions
 static gchar *
@@ -106,7 +120,7 @@ get_option(const gchar *dsn, const gchar *opt_name);
 
 
 gboolean
-gda_sybase_connection_new(Gda_ServerConnection *cnc)
+gda_sybase_connection_new(GdaServerConnection *cnc)
 {
   static gboolean initialized;
   sybase_Connection *scnc = NULL;
@@ -162,7 +176,7 @@ gda_sybase_connection_new(Gda_ServerConnection *cnc)
 }
 
 gint
-gda_sybase_connection_open(Gda_ServerConnection *cnc,
+gda_sybase_connection_open(GdaServerConnection *cnc,
                            const gchar* dsn,
                            const gchar* user,
                            const gchar* passwd)
@@ -186,7 +200,7 @@ gda_sybase_connection_open(Gda_ServerConnection *cnc,
 }
 
 void
-gda_sybase_connection_close(Gda_ServerConnection *cnc)
+gda_sybase_connection_close(GdaServerConnection *cnc)
 {
   sybase_Connection *scnc;
   
@@ -231,29 +245,29 @@ gda_sybase_connection_close(Gda_ServerConnection *cnc)
 }
 
 gint
-gda_sybase_connection_begin_transaction(Gda_ServerConnection *cnc)
+gda_sybase_connection_begin_transaction(GdaServerConnection *cnc)
 {
   // FIXME: Implement transaction code
   return -1;
 }
 
 gint
-gda_sybase_connection_commit_transaction(Gda_ServerConnection *cnc)
+gda_sybase_connection_commit_transaction(GdaServerConnection *cnc)
 {
   // FIXME: Implement transaction code
   return -1;
 }
 
 gint
-gda_sybase_connection_rollback_transaction(Gda_ServerConnection *cnc)
+gda_sybase_connection_rollback_transaction(GdaServerConnection *cnc)
 {
   // FIXME: Implement transaction code
   return -1;
 }
 
-Gda_ServerRecordset *
-gda_sybase_connection_open_schema (Gda_ServerConnection *cnc,
-				   Gda_ServerError *error,
+GdaServerRecordset *
+gda_sybase_connection_open_schema (GdaServerConnection *cnc,
+				   GdaServerError *error,
 				   GDA_Connection_QType t,
 				   GDA_Connection_Constraint *constraints,
 				   gint length)
@@ -273,7 +287,7 @@ gda_sybase_connection_open_schema (Gda_ServerConnection *cnc,
 }
 
 glong
-gda_sybase_connection_modify_schema (Gda_ServerConnection *cnc,
+gda_sybase_connection_modify_schema (GdaServerConnection *cnc,
                                    GDA_Connection_QType t,
                                    GDA_Connection_Constraint *constraints,
                                    gint length)
@@ -282,7 +296,7 @@ gda_sybase_connection_modify_schema (Gda_ServerConnection *cnc,
 }
 
 gint
-gda_sybase_connection_start_logging(Gda_ServerConnection *cnc,
+gda_sybase_connection_start_logging(GdaServerConnection *cnc,
                                     const gchar *filename)
 {
   // FIXME: Implement gda logging facility
@@ -290,14 +304,14 @@ gda_sybase_connection_start_logging(Gda_ServerConnection *cnc,
 }
 
 gint
-gda_sybase_connection_stop_logging(Gda_ServerConnection *cnc)
+gda_sybase_connection_stop_logging(GdaServerConnection *cnc)
 {
   // FIXME: Implement gda logging facility
   return -1;
 }
 
 gchar *
-gda_sybase_connection_create_table (Gda_ServerConnection *cnc,
+gda_sybase_connection_create_table (GdaServerConnection *cnc,
                                    GDA_RowAttributes *columns)
 {
   // FIXME: Implement creation of tables
@@ -305,7 +319,7 @@ gda_sybase_connection_create_table (Gda_ServerConnection *cnc,
 }
 
 gboolean
-gda_sybase_connection_supports(Gda_ServerConnection *cnc,
+gda_sybase_connection_supports(GdaServerConnection *cnc,
                                GDA_Connection_Feature feature)
 {
   g_return_val_if_fail(cnc != NULL, FALSE);
@@ -331,28 +345,40 @@ gda_sybase_connection_supports(Gda_ServerConnection *cnc,
 }
 
 const GDA_ValueType
-gda_sybase_connection_get_gda_type(Gda_ServerConnection *cnc,
+gda_sybase_connection_get_gda_type(GdaServerConnection *cnc,
                                    gulong sql_type)
 {
   return sybase_get_gda_type((CS_INT) sql_type);
 }
 
 const CS_INT
-gda_sybase_connection_get_sql_type (Gda_ServerConnection *cnc,
+gda_sybase_connection_get_sql_type (GdaServerConnection *cnc,
                                     GDA_ValueType gda_type)
 {
   return sybase_get_sql_type(gda_type);
 }
 
 const gshort
-gda_sybase_connection_get_c_type (Gda_ServerConnection *cnc,
+gda_sybase_connection_get_c_type (GdaServerConnection *cnc,
                                   GDA_ValueType gda_type)
 {
   return sybase_get_c_type(gda_type);
 }
 
+gchar *
+gda_sybase_connection_sql2xml (GdaServerConnection *cnc, const gchar *sql)
+{
+  return NULL;
+}
+
+gchar *
+gda_sybase_connection_xml2sql (GdaServerConnection *cnc, const gchar *xml)
+{
+  return NULL;
+}
+
 void
-gda_sybase_connection_free (Gda_ServerConnection *cnc)
+gda_sybase_connection_free (GdaServerConnection *cnc)
 {
   sybase_Connection* scnc;
   
@@ -367,7 +393,7 @@ gda_sybase_connection_free (Gda_ServerConnection *cnc)
 }
 
 void
-gda_sybase_connection_clear_user_data(Gda_ServerConnection *cnc,
+gda_sybase_connection_clear_user_data(GdaServerConnection *cnc,
                                       gboolean force_set_null_pointers) {
   sybase_Connection *scnc = NULL;
 
@@ -396,15 +422,15 @@ gda_sybase_connection_clear_user_data(Gda_ServerConnection *cnc,
  * Schema functions
  */
 
-static Gda_ServerRecordset *
-schema_cols (Gda_ServerError *error,
-             Gda_ServerConnection *cnc,
+static GdaServerRecordset *
+schema_cols (GdaServerError *error,
+             GdaServerConnection *cnc,
              GDA_Connection_Constraint *constraints,
              gint length)
 {
   gchar*                     query = NULL;
-  Gda_ServerCommand*         cmd = NULL;
-  Gda_ServerRecordset*       recset = NULL;
+  GdaServerCommand*         cmd = NULL;
+  GdaServerRecordset*       recset = NULL;
   GDA_Connection_Constraint* ptr = NULL;
   gint                       cnt;
   gulong                     affected = 0;
@@ -477,15 +503,15 @@ schema_cols (Gda_ServerError *error,
   return NULL;
 }
 
-static Gda_ServerRecordset *
-schema_procs (Gda_ServerError *error,
-              Gda_ServerConnection *cnc,
+static GdaServerRecordset *
+schema_procs (GdaServerError *error,
+              GdaServerConnection *cnc,
               GDA_Connection_Constraint *constraints,
               gint length)
 {
   GString*                   query = NULL;
-  Gda_ServerCommand*         cmd = NULL;
-  Gda_ServerRecordset*       recset = NULL;
+  GdaServerCommand*         cmd = NULL;
+  GdaServerRecordset*       recset = NULL;
   GDA_Connection_Constraint* ptr = NULL;
   gboolean                   extra_info = FALSE;
   gint                       cnt;
@@ -554,15 +580,15 @@ schema_procs (Gda_ServerError *error,
   return recset; 
 }
 
-static Gda_ServerRecordset *
-schema_tables (Gda_ServerError *error,
-               Gda_ServerConnection *cnc,
+static GdaServerRecordset *
+schema_tables (GdaServerError *error,
+               GdaServerConnection *cnc,
                GDA_Connection_Constraint *constraints,
                gint length)
 {
   GString*                   query = NULL;
-  Gda_ServerCommand*         cmd = NULL;
-  Gda_ServerRecordset*       recset = NULL;
+  GdaServerCommand*         cmd = NULL;
+  GdaServerRecordset*       recset = NULL;
   GDA_Connection_Constraint* ptr = NULL;
   gboolean                   extra_info = FALSE;
   gint                       cnt;
@@ -631,14 +657,14 @@ schema_tables (Gda_ServerError *error,
   return recset; 
 }
 
-static Gda_ServerRecordset *
-schema_types(Gda_ServerError *error,
-             Gda_ServerConnection *cnc,
+static GdaServerRecordset *
+schema_types(GdaServerError *error,
+             GdaServerConnection *cnc,
              GDA_Connection_Constraint *constraints,
              gint length)
 {
-  Gda_ServerCommand         *cmd = NULL;
-  Gda_ServerRecordset       *rec = NULL;
+  GdaServerCommand         *cmd = NULL;
+  GdaServerRecordset       *rec = NULL;
   GDA_Connection_Constraint *ptr = NULL;
   gint                      i   = 0;
   GString                   *query = NULL;
@@ -699,7 +725,7 @@ schema_types(Gda_ServerError *error,
     rec = gda_server_command_execute(cmd, error, NULL, &affected, 0);
     return rec;
   } else {
-    gda_log_error(_("Could not allocate Gda_ServerCommand"));
+    gda_log_error(_("Could not allocate GdaServerCommand"));
     g_string_free(query, TRUE);
   }
   
@@ -716,7 +742,7 @@ where o.type = 'V'
 */
 
 gboolean
-gda_sybase_connection_dead(Gda_ServerConnection *cnc)
+gda_sybase_connection_dead(GdaServerConnection *cnc)
 {
   sybase_Connection *scnc;
   CS_INT            con_status = 0;
@@ -744,10 +770,10 @@ gda_sybase_connection_dead(Gda_ServerConnection *cnc)
   return TRUE;
 }
 
-// do NOT call this before having freed Gda_ServerCommand structures
+// do NOT call this before having freed GdaServerCommand structures
 // associated to the given connection
 gboolean
-gda_sybase_connection_reopen(Gda_ServerConnection *cnc)
+gda_sybase_connection_reopen(GdaServerConnection *cnc)
 {
   sybase_Connection    *scnc;
   gboolean             first_connection = TRUE;
@@ -927,7 +953,7 @@ gda_sybase_connection_reopen(Gda_ServerConnection *cnc)
 }
 
 CS_RETCODE
-gda_sybase_connection_select_database(Gda_ServerConnection *cnc,
+gda_sybase_connection_select_database(GdaServerConnection *cnc,
                                       const gchar *database)
 {
   sybase_Connection *scnc = NULL;
@@ -1011,7 +1037,7 @@ gda_sybase_connection_select_database(Gda_ServerConnection *cnc,
 
 // Select locale for connection; we just need a CS_CONTEXT at this time
 static gboolean
-gda_sybase_set_locale(Gda_ServerConnection *cnc, const gchar *dsn)
+gda_sybase_set_locale(GdaServerConnection *cnc, const gchar *dsn)
 {
   sybase_Connection *scnc;
   CS_LOCALE         *locale;
@@ -1083,7 +1109,7 @@ gda_sybase_cleanup(sybase_Connection *scnc, CS_RETCODE ret, const gchar *msg)
  */
 
 static gint
-gda_sybase_init_dsn_properties(Gda_ServerConnection *cnc, const gchar *dsn)
+gda_sybase_init_dsn_properties(GdaServerConnection *cnc, const gchar *dsn)
 {
   sybase_Connection *scnc;
   gchar             *ptr_s, *ptr_e;
